import java.awt.*;
import java.awt.geom.*;
import java.lang.Math.*;

/**
 * Implementacion de la figura geometrica Circulo
 * @author Carlos Cortes
*/
public class Circulo extends Forma
{
    /**
     * Ubicacion del punto central
     */
    private Point2D.Double posicion;
    
    /**
     * Radio
     */
    private double radio;
    
    /**
     * Constructor.
     * Crea e inicializa un nuevo Circulo
     * @param centro Punto central del circulo
     * @param radio Radio del circulo
     */
    public Circulo(Point centro, double radio)
    {
        double x, y;
        
        x = centro.getX();
        y = centro.getY();
        this.posicion = new Point2D.Double(x, y);
        
        if (radio >= 0)
            this.radio = radio;
        else
            this.radio = -radio;
    }
    
    /**
     * Retorna la posicion del circulo
     */
    public Point2D.Double getPosicion()
    {
        return this.posicion;
    }
    
    /**
     * Retorna el radio del circulo
     */
    public double getRadio()
    {
        return this.radio;
    }
    
    /**
     * Establece la posicion del circulo
     */
    public void setPosicion(Point2D.Double newPos)
    {
        this.posicion = newPos;
        return;
    }
    
    /**
     * Establece el radio del circulo
     */
    public void setRadio(double newRadio)
    {
        this.radio = newRadio;
        return;
    }
    
    public void escalar(Point centro, double factor)
    {
        double fx, fy;
        
        fx = this.posicion.getX() - centro.getX();
        fy = this.posicion.getY() - centro.getY();
        fx *= factor;
        fy *= factor;
        fx += centro.getX();
        fy += centro.getY();
        
        this.posicion.setLocation(fx, fy);
        
        this.radio *= factor;
        
        return;
    }
    
    public void rotar(Point centro, double deltaAngulo)
    {
        double fx, fy,  // vector posicion antes del giro
               rx, ry,  // vetor auxiliar para el calculo
               gx, gy;  // vector posicion despues del giro
        
        // Se hace que 'centro' sea el origen de coordenadas
        fx = this.posicion.getX() - centro.getX();
        fy = this.posicion.getY() - centro.getY();
        
        // Se calcula la componente X del nuevo vector posicion
        deltaAngulo *= -1;
        rx = Math.cos(deltaAngulo);
        ry = Math.sin(deltaAngulo);
        gx = fx*rx + fy*ry;
        
        // Se calcula la componente Y del nuevo vetor posicion
        deltaAngulo += Math.PI/2;
        rx = Math.cos(deltaAngulo);
        ry = Math.sin(deltaAngulo);
        gy = fx*rx + fy*ry;
        
        // Se traslada 'centro' a su posicion original
        gx += centro.getX();
        gy += centro.getY();
        this.posicion.setLocation(gx, gy);
        
        return;
    }
    
    public void trasladar(double deltaX, double deltaY)
    {
        this.posicion.setLocation(this.posicion.getX() + deltaX,
                                  this.posicion.getY() + deltaY);
        return;
    }
    
    /**
     * Retorna un String que describe la informacion mas relevante del Circulo.
     * Se limita la presicion a dos decimales (por redondeo).
     */
    public String toString()
    {
        return "Este es un Circulo: Centro=( "
               + Math.rint(this.posicion.getX()*100)/100.0
               + " , "
               + Math.rint(this.posicion.getY()*100)/100.0
               + " ) ; Radio="
               + Math.rint(this.radio*100)/100.0;
    }
    
    /**
     * Indica si el circulo (this) es igual a otro
     */
    public boolean equals(Circulo otro)
    {
        if (this == otro) return true;
        if (otro == null) return false;
        if (this.getClass() != otro.getClass()) return false;
        
        if (this.posicion.equals(otro.getPosicion()) &&
            this.radio == otro.getRadio()
           )
            return true;
        else
            return false;
    }
    
    /**
     * Crea otro circulo identico
     */
    public Circulo clone()
    {
        Circulo hijo = new Circulo(new Point(), 0);
        hijo.setPosicion(this.getPosicion());
        hijo.setRadio(this.getRadio());
        return hijo;
    }
}