import java.util.*;
import java.awt.*;
import java.awt.geom.*;
import java.lang.Math.*;

/**
 * Subclase de Forma
 * Corresponde a un grupo de varias Formas que se comportan como una sola gran Forma
 * Las Formas que pertenezcan al mismo grupo podran ser manipuladas como si se tratara de una sola
 * @author Carlos Cortes
 */
public class Figura extends Forma
{
    /**
     * Lista con las referencias a las Formas que integran la Figura
     */
    private ArrayList<Forma> grupo;
    
    /**
     * Constructor.
     * Crea una Figura vacia a la que se le pueden agregar diferentes Formas
     */
    public Figura()
    {
        grupo = new ArrayList<Forma>();
    }
    
    /**
     * Agrega una Forma a la Figura
     * @param nueva Forma que se agregara
     */
    public void agregar(Forma nueva)
    {
        grupo.add(nueva);
    }
    
    /**
     * Retorna la cantidad de Formas contenidas en la Figura
     */
    public int totalFormas()
    {
        return grupo.size();
    }
    
    /**
     * Retorna la Forma almacenada en la posicion 'id'
     * @param id Numero identificador del elemento
     */
    public Forma getForma(int id)
    {
        return grupo.get(id);
    }
    
    public void escalar(Point centro, double factor)
    {
        int i;
        for (i=0 ; i<grupo.size() ; i++)
            (grupo.get(i)).escalar(centro, factor);
    }
    
    public void rotar(Point centro, double deltaAngulo)
    {
        int i;
        for (i=0 ; i<grupo.size() ; i++)
            (grupo.get(i)).rotar(centro, deltaAngulo);
    }
    
    public void trasladar(double deltaX, double deltaY)
    {
        int i;
        for (i=0 ; i<grupo.size() ; i++)
            (grupo.get(i)).trasladar(deltaX, deltaY);
    }
    
    /**
     * Retorna un String que describe la informacion mas relevante de la Figura
     */
    public String toString()
    {
        StringBuffer info = new StringBuffer();
        int i;
        
        info.append("Esta es una Figura compuesta por " + grupo.size() + " Formas:\n");
        if (grupo.size() == 0)
        {
            info.append("  Figura vacia\n");
            return info.toString();
        }
        
        for (i=0 ; i<grupo.size() ; i++)
        {
            info.append("  [" + (i+1) + "]: " + (grupo.get(i)).toString() + "\n");
        }
        
        return info.toString();
    }
}