import java.awt.*;

/**
 * Superclass para distintas formas en R2.
 * @author Agustin J. Gonzalez
 */
public abstract class Forma
{
    /**
     * Escala la forma respecto al punto central en un factor dado.
     * @param centro Punto respecto del cual se hace el escalamiento.
     * @param factor Factor usado en el escalamiento. >1 corresponde a amplificacion, <1 corresponde a reduccion.
     */
    public abstract void escalar(Point centro, double factor);

    /**
     * Rota la forma respecto al punto central en un angulo dado.
     * @param centro Punto respecto del cual se hace la rotacion.
     * @param deltaAngulo Angulo de rotacion en radianes.
     */
    public abstract void rotar(Point centro, double deltaAngulo);

    /**
     * Traslada la forma desplazandola en sentido X e Y.
     * @param deltaX desplazamiento en sentido horizontal.
     * @param deltaY desplazamiento en sentido vertical.
     */
    public abstract void trasladar(double deltaX, double deltaY);
}