import java.awt.*;
import java.io.*;
import java.lang.Math.*;
import java.util.Scanner;

/**
 * Menu por consola que permite crear y manipular Formas
 * @author Carlos Cortes
 */
public class TestFigura
{
    /**
     * Figura que sera manipulada
     */
    private Figura dibujo;
    
    /**
     * Constructor
     * Crea una sesion del editor de Formas (un menu por consola)
     * @param grupo Figura que sera sometida al Test
     */
    public TestFigura(Figura grupo)
    {
        dibujo = grupo;
    }
    
    /**
     * Muestra un menu por consola que permite agregar nuevas formas a la figura
     * @return La figura creada
     */
    public Forma figuraFactory()
    {
        Scanner teclado = new Scanner (System.in);
        Forma recienCreada;
        int accion, x1, y1, x2, y2;
        double r;
        
        do
        {
            System.out.println("AGREGAR NUEVA FORMA");
            System.out.println("===================");
            System.out.println("1: Crear Rectangulo");
            System.out.println("2: Crear Circulo");
            System.out.println("3: Salir");
        
            do
            {
                System.out.print("  Ingrese accion (1,2,3): ");
            
                while(!teclado.hasNextInt())
                {
                    teclado.nextLine();
                    System.out.print("  Ingrese accion (1,2,3): ");
                }
                accion = teclado.nextInt();
            } while(accion < 1 || accion > 3);
            System.out.print("\n");
            
            switch (accion)
            {
                case 1: System.out.println("Creando un Rectangulo desde (x1,y1) hasta (x2,y2)");
                        System.out.print("  (int) x1? : ");
                        while(!teclado.hasNextInt())
                        {
                            teclado.nextLine();
                            System.out.print("  (int) x1? : ");
                        }
                        x1 = teclado.nextInt();
                        
                        System.out.print("  (int) y1? : ");
                        while(!teclado.hasNextInt())
                        {
                            teclado.nextLine();
                            System.out.print("  (int) y1? : ");
                        }
                        y1 = teclado.nextInt();
                        
                        System.out.print("  (int) x2? : ");
                        while(!teclado.hasNextInt())
                        {
                            teclado.nextLine();
                            System.out.print("  (int) x2? : ");
                        }
                        x2 = teclado.nextInt();
                        
                        System.out.print("  (int) y2? : ");
                        while(!teclado.hasNextInt())
                        {
                            teclado.nextLine();
                            System.out.print("  (int) y2? : ");
                        }
                        y2 = teclado.nextInt();
                        System.out.print("\n");
                        
                        recienCreada = new Rectangulo(new Point(x1,y1), new Point(x2,y2));
                        dibujo.agregar(recienCreada);
                        System.out.println(dibujo.toString());
                        break;
                
                case 2: System.out.println("Creando un Circulo en '(x,y)' y radio 'r'");
                        System.out.print("  (int)  x? : ");
                        while(!teclado.hasNextInt())
                        {
                            teclado.nextLine();
                            System.out.print("  (int)  x? : ");
                        }
                        x1 = teclado.nextInt();
                        
                        System.out.print("  (int)  y? : ");
                        while(!teclado.hasNextInt())
                        {
                            teclado.nextLine();
                            System.out.print("  (int)  y? : ");
                        }
                        y1 = teclado.nextInt();
                        
                        System.out.print("(double) r? : ");
                        while(!teclado.hasNextDouble())
                        {
                            teclado.nextLine();
                            System.out.print("(double) r? : ");
                        }
                        r = teclado.nextDouble();
                        System.out.print("\n");
                        
                        recienCreada = new Circulo(new Point(x1,y1), r);
                        dibujo.agregar(recienCreada);
                        System.out.println(dibujo.toString());
                        break;
            }
            
        } while(accion != 3);
        return dibujo;
    }
    
    /**
     * Muestra un menu por consola que permite manipular una Forma especifica
     * @param f Forma que se va a manipular
     */
    public void manipularForma(Forma f)
    {
        Scanner teclado = new Scanner (System.in);
        
        do
        {
            System.out.println("MANIPULAR FIGURA");
            System.out.println("================");
            System.out.println("1: rotar");
            System.out.println("2: trasladar");
            System.out.println("3: escalar");
            System.out.println("4: Salir");
            
            int accion, x, y;
            double dx, dy, a, z;
            do
            {
                System.out.print("  Ingrese accion (1,2,3,4): ");
                while(!teclado.hasNextInt())
                {
                    teclado.nextLine();
                    System.out.print("  Ingrese accion (1,2,3,4): ");
                }
                accion = teclado.nextInt();
            } while(accion < 1 || accion > 4);
            System.out.print("\n");
            
            switch (accion)
            {
                case 1: System.out.println("respecto a '(x,y)', rotar 'a' grados");
                        System.out.print("  (int)   x? : ");
                        while(!teclado.hasNextInt())
                        {
                            teclado.nextLine();
                            System.out.print("  (int)   x? : ");
                        }
                        x = teclado.nextInt();
                        
                        System.out.print("  (int)   y? : ");
                        while(!teclado.hasNextInt())
                        {
                            teclado.nextLine();
                            System.out.print("  (int)   y? : ");
                        }
                        y = teclado.nextInt();
                        
                        System.out.print("(double)  a? : ");
                        while(!teclado.hasNextDouble())
                        {
                            teclado.nextLine();
                            System.out.print("(double)  a? : ");
                        }
                        a = Math.toRadians(teclado.nextDouble());// * Math.PI / 180;
                        System.out.print("\n");
                        
                        f.rotar(new Point(x,y), a);
                        break;
                
                case 2: System.out.println("traslado relativo '(dx,dy)'");
                        System.out.print("(double) dx? : ");
                        while(!teclado.hasNextDouble())
                        {
                            teclado.nextLine();
                            System.out.print("(double) dx? : ");
                        }
                        dx = teclado.nextDouble();
                        
                        System.out.print("(double) dy? : ");
                        while(!teclado.hasNextDouble())
                        {
                            teclado.nextLine();
                            System.out.print("(double) dy? : ");
                        }
                        dy = teclado.nextDouble();
                        System.out.print("\n");
                        
                        f.trasladar(dx, dy);
                        break;

                case 3: System.out.println("respecto a (x,y), escalar a 'z' veces el original");
                        System.out.print("  (int)   x? : ");
                        while(!teclado.hasNextInt())
                        {
                            teclado.nextLine();
                            System.out.print("  (int)   x? : ");
                        }
                        x = teclado.nextInt();
                        
                        System.out.print("  (int)   y? : ");
                        while(!teclado.hasNextInt())
                        {
                            teclado.nextLine();
                            System.out.print("  (int)   y? : ");
                        }
                        y = teclado.nextInt();
                        
                        System.out.print("(double)  z? : ");
                        while(!teclado.hasNextDouble())
                        {
                            teclado.nextLine();
                            System.out.print("(double)  z? : ");
                        }
                        z = teclado.nextDouble();
                        System.out.print("\n");
                        
                        f.escalar(new Point(x,y), z);
                        break;
                        
                case 4: return;
            }
            System.out.println(f.toString());
        } while(true);
        //return;
    }
    
    public static void main(String[] args)
    {
        System.out.println("\nFiguraTest v1.0 for Java 1.5.0");
                
        Figura dibujo = new Figura();
        Forma f;
        TestFigura editor = new TestFigura(dibujo);
        
        f = editor.figuraFactory();
        System.out.println(f.toString());

        editor.manipularForma(f);
        
        System.out.println("Terminado");
        return;
    }
}